package com.ruoyi.system.mapper.project;

import com.ruoyi.system.domain.project.BmDeptPlan;
import com.ruoyi.system.domain.vo.BmDeptPlanVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 *  部门招商计划Mapper接口
 * 
 * @author ruoyi
 * @date 2021-03-09
 */
public interface BmDeptPlanMapper
{
    /**
     * 查询 部门招商计划
     * 
     * @param id  部门招商计划ID
     * @return  部门招商计划
     */
    public BmDeptPlan selectBmDeptPlanById(Long id);

    /**
     * 查询 部门招商计划列表
     * 
     * @param bmDeptPlan  部门招商计划
     * @return  部门招商计划集合
     */
    public List<BmDeptPlan> selectBmDeptPlanList(BmDeptPlan bmDeptPlan);

    /**
     * 新增 部门招商计划
     * 
     * @param bmDeptPlan  部门招商计划
     * @return 结果
     */
    public int insertBmDeptPlan(BmDeptPlan bmDeptPlan);

    /**
     * 修改 部门招商计划
     * 
     * @param bmDeptPlan  部门招商计划
     * @return 结果
     */
    public int updateBmDeptPlan(BmDeptPlan bmDeptPlan);

    /**
     * 删除 部门招商计划
     * 
     * @param id  部门招商计划ID
     * @return 结果
     */
    public int deleteBmDeptPlanById(Long id);

    /**
     * 批量删除 部门招商计划
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBmDeptPlanByIds(Long[] ids);

    /**
     * 首页-市值榜单
     * @return
     */
    public List<BmDeptPlan> selectUnitList(@Param("year") String year);



    /**
     * 统计分析-在谈线索-两区及乡镇
     * @return
     */
    public List<BmDeptPlanVo> selectUnitClueList(@Param("year")String year);

    /**
     * 统计分析-在谈线索-市直榜单
     * @return
     */
    public List<BmDeptPlanVo> selectUnitClueCityList(@Param("year")String year);

    /**
     * 两区及乡镇榜单
     * @return
     */
    public List<BmDeptPlanVo> selectTargetSigningList(@Param("year")String year);

    /**
     * 统计分析-签约项目-市直榜单
     * @return
     */
    public List<BmDeptPlanVo> selectTotAmtList(@Param("year")String year);

    /**
     * 统计分析-在建项目-柱状图
     * @return
     */
    public List<BmDeptPlanVo> selectProjectUnitAmountEharts(@Param("year")String year);

    /**
     * 统计分析-在建项目-市直榜单
     * @param year
     * @return
     */
    public List<BmDeptPlanVo> selectProjectUnitAmountUnit(@Param("year")String year);

    /**
     * 统计分析-在建项目-两区及乡镇
     * @param year
     * @return
     */
    public List<BmDeptPlanVo> selectProjectAreaAmountUnit(@Param("year")String year);

    /**
     * 统计分析-投产项目-两区及乡镇入归榜单
     * >8 根据字典值来判断是否是已经入归(项目完成)状态
     * @return
     */
    public List<BmDeptPlanVo> selectInvestmentList(@Param("year")String year);

    /**
     * 统计分析-投产项目-市直榜单
     * >8 根据字典值来判断是否是已经入归(项目完成)状态
     * @return
     */
    public List<BmDeptPlanVo> selectInvestmentCityList(@Param("year")String year);

    /**
     * 统计分析-投产项目-柱状图
     * @param year
     * @return
     */
    public List<BmDeptPlanVo> selectProjectInvestmentEharts(@Param("year")String year);


}
